@@ -67,6 +67,7 @@ Preferences preferences =
      296.98,		/* fax_height: height of fax paper in mm */
        0.0,             /* fax_leftoffset */
        0.0,             /* fax_bottomoffset */
+       1,               /* fax_fine_mode */
 #ifdef XSANE_ACTIVATE_MAIL
        0,               /* no default from email address */
        0,               /* no default reply to email address */
@@ -79,6 +80,7 @@ Preferences preferences =
        0,               /* no default pop3 passsword */
        0,		/* no mail project */
        0,		/* no mail viewer */
+       0,		/* no mail filetype */
 #endif
        0,		/* no default ocrcommand */
        0,		/* no default ocr input file option */
@@ -170,6 +172,7 @@ desc[] =
     {"fax-height",			xsane_rc_pref_double,	POFFSET(fax_height)},
     {"fax-left-offset",			xsane_rc_pref_double,	POFFSET(fax_leftoffset)},
     {"fax-bottom-offset",		xsane_rc_pref_double,	POFFSET(fax_bottomoffset)},
+    {"fax-fine-mode",			xsane_rc_pref_int,	POFFSET(fax_fine_mode)},
 #ifdef XSANE_ACTIVATE_MAIL
     {"mail-from",			xsane_rc_pref_string,	POFFSET(mail_from)},
     {"mail-reply-to",			xsane_rc_pref_string,	POFFSET(mail_reply_to)},
@@ -182,6 +185,7 @@ desc[] =
     {"mail-pop3-pass",			xsane_rc_pref_string,	POFFSET(mail_pop3_pass)},
     {"mail-project",			xsane_rc_pref_string,	POFFSET(mail_project)},
     {"mail-viewer",			xsane_rc_pref_string,	POFFSET(mail_viewer)},
+    {"mail-filetype",			xsane_rc_pref_string,	POFFSET(mail_filetype)},
 #endif
     {"ocr-command",			xsane_rc_pref_string,	POFFSET(ocr_command)},
     {"ocr-inputfile-option",		xsane_rc_pref_string,	POFFSET(ocr_inputfile_option)},
@@ -189,7 +193,7 @@ desc[] =
     {"ocr-use-gui-pipe",		xsane_rc_pref_int,	POFFSET(ocr_use_gui_pipe)},
     {"ocr-gui-outfd-option",		xsane_rc_pref_string,	POFFSET(ocr_gui_outfd_option)},
     {"ocr-progress-keyword",		xsane_rc_pref_string,	POFFSET(ocr_progress_keyword)},
-    {"doc-viewer",			xsane_rc_pref_string,	POFFSET(doc_viewer)},
+    {"browser",				xsane_rc_pref_string,	POFFSET(browser)},
     {"jpeg-quality",			xsane_rc_pref_double,	POFFSET(jpeg_quality)},
     {"png-compression",			xsane_rc_pref_double, 	POFFSET(png_compression)},
     {"tiff-compression16_nr",		xsane_rc_pref_int, 	POFFSET(tiff_compression16_nr)},
@@ -241,7 +245,6 @@ desc[] =
     {"gtk-update-policy",		xsane_rc_pref_int,	POFFSET(gtk_update_policy)},
     {"paper-orientation",		xsane_rc_pref_int,	POFFSET(paper_orientation)},
     {"preset-area-definitions",		xsane_rc_pref_int,	POFFSET(preset_area_definitions)},
-    {"medium-definitions",		xsane_rc_pref_int,	POFFSET(medium_definitions)},
     {"printernr",			xsane_rc_pref_int,	POFFSET(printernr)},
     {"printerdefinitions",		xsane_rc_pref_int,	POFFSET(printerdefinitions)}
   };
@@ -367,23 +370,6 @@ void preferences_save(int fd)
     n++;
   }
 
-  /* save mediums */
-
-  n=0;
-
-  while (n < preferences.medium_definitions)
-  {
-    DBG(DBG_info2, "saving preferences medium definition %s\n", preferences.medium[n]->name);
-    for (i = 0; i < NELEMS(desc_medium); ++i)
-    {
-      xsane_rc_io_w_string(&w, &desc_medium[i].name);
-      (*desc_medium[i].codec) (&w, preferences.medium[n], desc_medium[i].offset);
-    }
-    n++;
-  }
-
-
-
   xsane_rc_io_w_set_dir(&w, WIRE_DECODE);	/* flush it out */
   xsane_rc_io_w_exit(&w);
 }
@@ -410,28 +396,43 @@ void preferences_restore(int fd)
     if (w.status)
     {
       xsane_rc_io_w_exit(&w);
+      preferences.printerdefinitions = 0;
+      preferences.preset_area_definitions = 0;
      return;
     }
 
     xsane_rc_io_w_string(&w, &name);
-    if (w.status || !name)
+    if (w.status == EINVAL) /* not a string */
+    {
+      w.status = 0;
+      xsane_rc_io_w_skip_newline(&w); /* skip this line */
+    }
+    else if (w.status || !name) /* other error */
     {
       xsane_rc_io_w_exit(&w);
      return;
     }
-
-    for (i = 0; i < NELEMS (desc); ++i)
+    else /* identifier read */
     {
-      if (strcmp(name, desc[i].name) == 0)
+      for (i = 0; i < NELEMS(desc); ++i)
+      {
+        if (strcmp(name, desc[i].name) == 0)
+        {
+          DBG(DBG_info2, "reading preferences value for %s\n", desc[i].name);
+          (*desc[i].codec) (&w, &preferences, desc[i].offset);
+          break;
+        }
+      }
+
+      if (!strcmp(name, "printerdefinitions"))
       {
-        DBG(DBG_info2, "reading preferences value for %s\n", desc[i].name);
-        (*desc[i].codec) (&w, &preferences, desc[i].offset);
         break;
       }
-    }
-    if (!strcmp(name, "printerdefinitions"))
-    {
-      break;
+      else if (i == NELEMS(desc))
+      {
+        DBG(DBG_info2, "preferences identifier %s unknown\n", name);
+        xsane_rc_io_w_skip_newline(&w); /* skip this line */
+      }
     }
   }
 
@@ -514,8 +515,94 @@ void preferences_restore(int fd)
     }
   }
 
+  xsane_rc_io_w_exit(&w);
+}
+
+/* --------------------------------------------------------------------- */
+/* --------------------------------------------------------------------- */
+
+void preferences_save_media(int fd)
+{
+ Wire w;
+ int i, n;
+ char *medium_defs="MEDIUM_DEFINITIONS";
+
+  DBG(DBG_proc, "preferences_save_media\n");
+
+  w.io.fd = fd;
+  w.io.read = read;
+  w.io.write = write;
+  xsane_rc_io_w_init(&w);
+  xsane_rc_io_w_set_dir(&w, WIRE_ENCODE);
+
+  xsane_rc_io_w_string(&w, &medium_defs);
+  xsane_rc_io_w_word(&w, &preferences.medium_definitions);
+
+  /* save media */
+
+  n=0;
+
+  DBG(DBG_info, "saving %d medium definitions\n", preferences.medium_definitions);
+
+  while (n < preferences.medium_definitions)
+  {
+    DBG(DBG_info2, "=> saving medium definition %s\n", preferences.medium[n]->name);
+    for (i = 0; i < NELEMS(desc_medium); ++i)
+    {
+      xsane_rc_io_w_string(&w, &desc_medium[i].name);
+      (*desc_medium[i].codec) (&w, preferences.medium[n], desc_medium[i].offset);
+    }
+    n++;
+  }
+
+  xsane_rc_io_w_set_dir(&w, WIRE_DECODE);	/* flush it out */
+  xsane_rc_io_w_exit(&w);
+}
+
+/* --------------------------------------------------------------------- */
+
+void preferences_restore_media(int fd)
+{
+ SANE_String name;
+ Wire w;
+ int i, n;
+
+  DBG(DBG_proc, "preferences_restore_media\n");
+
+  w.io.fd = fd;
+  w.io.read = read;
+  w.io.write = write;
+  xsane_rc_io_w_init(&w);
+  xsane_rc_io_w_set_dir(&w, WIRE_DECODE);
+
+  preferences.medium_definitions = 0;
+
+  xsane_rc_io_w_space(&w, 3);
+  if (w.status)
+  {
+    xsane_rc_io_w_exit(&w);
+   return;
+  }
+
+  xsane_rc_io_w_string(&w, &name);
+  if (w.status || !name)
+  {
+    xsane_rc_io_w_exit(&w);
+   return;
+  }
+
+  if (strcmp(name, "MEDIUM_DEFINITIONS")) /* falsche Datei */
+  {
+    DBG(DBG_info, "no medium definitions in file\n");
+    xsane_rc_io_w_exit(&w);
+   return;
+  }
+
+  xsane_rc_io_w_word(&w, &preferences.medium_definitions);
+
   if (preferences.medium_definitions)
   {
+    DBG(DBG_info, "reading %d medium definition\n", preferences.medium_definitions);
     preferences.medium = calloc(preferences.medium_definitions, sizeof(void *)); 
 
     n=0;
@@ -547,10 +634,12 @@ void preferences_restore(int fd)
           break;
         }
       }
-      DBG(DBG_info2, "preferences medium definition %s read\n", preferences.medium[n]->name);
+      DBG(DBG_info2, "=> medium definition %s read\n", preferences.medium[n]->name);
       n++;
     }
   }
 
   xsane_rc_io_w_exit(&w);
 }
+
+/* --------------------------------------------------------------------- */
