@@ -33,6 +33,8 @@
 
 #define XSANE_COPYRIGHT_SIGN		_("(c)") /* can be translated with \251 */
 
+#define FILENAME_PREFIX_CLONE_OF	_("clone-of-")
+
 #define WINDOW_ABOUT_XSANE		_("About")
 #define WINDOW_ABOUT_TRANSLATION	_("About translation")
 #define WINDOW_AUTHORIZE		_("authorization")
@@ -50,6 +52,9 @@
 #define WINDOW_MAIL_RENAME		_("rename mail image")
 #define WINDOW_MAIL_INSERT		_("insert file into mail")
 #define WINDOW_PRESET_AREA_RENAME	_("rename preset area")
+#define WINDOW_PRESET_AREA_ADD		_("add preset area")
+#define WINDOW_MEDIUM_RENAME		_("rename medium")
+#define WINDOW_MEDIUM_ADD		_("add new medium")
 #define WINDOW_SETUP			_("setup")
 #define WINDOW_HISTOGRAM		_("Histogram")
 #define WINDOW_GAMMA			_("Gamma curve")
@@ -74,8 +79,11 @@
 #define MENU_FILE			_("File")
 #define MENU_PREFERENCES		_("Preferences")
 #define MENU_VIEW			_("View")
+#define MENU_WINDOW			_("Window")
 #define MENU_HELP			_("Help")
+#define MENU_EDIT			_("Edit")
 #define MENU_FILTERS			_("Filters")
+#define MENU_GEOMETRY			_("Geometry")
 
 #define MENU_ITEM_ABOUT_XSANE		_("About XSane")
 #define MENU_ITEM_ABOUT_TRANSLATION	_("About translation")
@@ -88,9 +96,17 @@
 #define MENU_ITEM_SCALE			_("Scale")
 #define MENU_ITEM_CLOSE			_("Close")
 
+#define MENU_ITEM_UNDO			_("Undo")
+
 #define MENU_ITEM_DESPECKLE		_("Despeckle")
 #define MENU_ITEM_BLUR			_("Blur")
 
+#define MENU_ITEM_ROTATE90		_("Rotate 90")
+#define MENU_ITEM_ROTATE180		_("Rotate 180")
+#define MENU_ITEM_ROTATE270		_("Rotate 270")
+#define MENU_ITEM_MIRROR_X		_("Mirror |")
+#define MENU_ITEM_MIRROR_Y		_("Mirror -")
+
 #define FRAME_RAW_IMAGE			_("Raw image")
 #define FRAME_ENHANCED_IMAGE		_("Enhanced image")
 
@@ -113,6 +129,7 @@
 #define BUTTON_PAGE_RENAME		_("Rename page")
 #define BUTTON_IMAGE_DELETE		_("Delete image")
 #define BUTTON_IMAGE_SHOW		_("Show image")
+#define BUTTON_IMAGE_EDIT		_("Edit image")
 #define BUTTON_IMAGE_RENAME		_("Rename image")
 #define BUTTON_FILE_INSERT		_("Insert file")
 #define BUTTON_CREATE_PROJECT		_("Create project")
@@ -222,6 +239,7 @@
 #define TEXT_MAIL_TEXT			_("Email text:")
 #define TEXT_ATTACHMENTS		_("Attachments:")
 #define TEXT_MAIL_STATUS		_("Project status:")
+#define TEXT_MAIL_FILETYPE		_("Mail image filetype:")
 
 #define TEXT_MEDIUM_DEFINITION_NAME	_("Medium Name:")
 
@@ -305,6 +323,7 @@
 #define TEXT_SETUP_PERMISSION_USER	_("user")
 #define TEXT_SETUP_PERMISSION_GROUP	_("group")
 #define TEXT_SETUP_PERMISSION_ALL	_("all")
+#define	TEXT_NEW_MEDIA_NAME		_("new media")
 
 #define NOTEBOOK_SAVING_OPTIONS		_("Save")
 #define NOTEBOOK_IMAGE_OPTIONS		_("Image")
@@ -375,10 +394,12 @@
 #define MENU_ITEM_FILETYPE_BY_EXT	_("by ext")
 
 #define MENU_ITEM_PRESET_AREA_ADD_SEL	_("Add selection to list")
-#define MENU_ITEM_PRESET_AREA_RENAME	_("Rename definiton")
-#define MENU_ITEM_PRESET_AREA_DELETE	_("Delete definition")
-#define MENU_ITEM_PRESET_AREA_MOVE_UP	_("Move up")
-#define MENU_ITEM_PRESET_AREA_MOVE_DWN	_("Move down")
+#define MENU_ITEM_MEDIUM_ADD		_("Add medium definition")
+
+#define MENU_ITEM_RENAME		_("Rename item")
+#define MENU_ITEM_DELETE		_("Delete item")
+#define MENU_ITEM_MOVE_UP		_("Move item up")
+#define MENU_ITEM_MOVE_DWN		_("Move item down")
 
 #define PROGRESS_SCANNING		_("Scanning")
 #define PROGRESS_RECEIVING_FRAME_DATA	_("Receiving %s data")
@@ -401,7 +422,9 @@
 #define DESC_PREVIEW_CANCEL		_("Cancel preview scan <Alt-ESC>")
 #define DESC_XSANE_MODE			_("save-<Ctrl-s>, view-<Ctrl-v>, photocopy-<Ctrl-c>, " \
 					  "fax-<Ctrl-f> or mail-<Ctrl-m>")
-#define DESC_XSANE_MEDIUM		_("Select source medium type\n")
+#define DESC_XSANE_MEDIUM		_("Select source medium type.\n" \
+					  "To rename, reorder or delete an entry use context menu (right mouse button).\n"\
+					  "To create a medium enable the option edit medium definition in preferences menu.")
 
 #define DESC_FILENAME_COUNTER_STEP	_("Value that is added to filenamecounter after scan")
 #define DESC_BROWSE_FILENAME		_("Browse for image filename")
@@ -414,8 +437,11 @@
 #define DESC_MAILIMAGENAME		_("Enter new name for mail image")
 #define DESC_MAILRECEIVER		_("Enter email address")
 #define DESC_MAILSUBJECT		_("Enter subject of email")
-#define DESC_PRESET_AREA_NAME		_("Enter new name for preset area")
-#define DESC_MEDIUM_DEFINITION_NAME	_("Enter new name for medium definition")
+#define DESC_MAIL_FILETYPE		_("Select filetype for image attachments")
+#define DESC_PRESET_AREA_RENAME		_("Enter new name for preset area")
+#define DESC_PRESET_AREA_ADD		_("Enter name for new preset area")
+#define DESC_MEDIUM_RENAME		_("Enter new name for medium definition")
+#define DESC_MEDIUM_ADD			_("Enter name for new medium definition")
 
 #define DESC_PRINTER_SELECT		_("Select printerdefinition <Shift-F1/F2/...>")
 
@@ -548,7 +574,7 @@
 #define DESC_POP3_USER			_("user name for POP3 server")
 #define DESC_POP3_PASS			_("password for POP3 server")
 #define DESC_MAIL_VIEWER		_("Enter command to be executed to view a mail image")
-#define DESC_HTML_MAIL			_("Mail is sent in html mode, images are displayed directly")
+#define DESC_HTML_MAIL			_("Mail is sent in html mode, place image with: <IMAGE>")
 #define DESC_OCR_COMMAND		_("Enter command to start ocr program")
 #define DESC_OCR_INPUTFILE_OPT		_("Enter option of the ocr program to define input file")
 #define DESC_OCR_OUTPUTFILE_OPT		_("Enter option of the ocr program to define output file")
@@ -576,13 +602,15 @@
 #define DESC_AUTORAISE_SCANAREA		_("Autoraise scanarea")
 #define DESC_DELETE_IMAGES		_("Delete preview image cache")
 
-#define DESC_PRESET_AREA		_("Preset area")
+#define DESC_PRESET_AREA		_("Preset area:\n" \
+					  "To add new area or edit an existing area use contect menu (right mouse button).")
 #define DESC_ROTATION			_("Rotate preview and scan")
 #define DESC_RATIO			_("Aspect ratio of selection")
 #define DESC_PAPER_ORIENTATION		_("Define image position for printing")
 
 #define DESC_VIEWER_SAVE		_("Save image")
 #define DESC_VIEWER_OCR			_("Optical Character Recognition")
+#define DESC_VIEWER_UNDO		_("Undo last change")
 #define DESC_VIEWER_CLONE		_("Clone image")
 #define DESC_VIEWER_SCALE		_("Scale image")
 #define DESC_VIEWER_DESPECKLE		_("Despeckle image")
@@ -636,6 +664,8 @@
 #define ERR_LIBJPEG			_("LIBJPEG reports error")
 #define ERR_UNKNOWN_TYPE		_("unknown type")
 #define ERR_UNKNOWN_CONSTRAINT_TYPE	_("unknown constraint type")
+#define ERR_OPTION_NAME_NULL		_("Option has empty name (NULL).")
+#define ERR_BACKEND_BUG			_("This is a backend bug. Please inform the author of the backend!")
 #define ERR_FAILED_EXEC_DOC_VIEWER	_("Failed to execute documentation viewer:")
 #define ERR_FAILED_EXEC_FAX_VIEWER	_("Failed to execute fax viewer:")
 #define ERR_FAILED_EXEC_FAX_CMD		_("Failed to execute fax command:")
@@ -774,4 +804,22 @@ The format of [DEVICE] is backendname:devicefile (e.g. umax:/dev/scanner).\n\
 #define MENU_ITEM_MEDIUM_KONICA_NEG_VX_100	N_("Konica negative VX 100")
 #define MENU_ITEM_MEDIUM_ROSSMANN_NEG_HR_100	N_("Rossmann negative HR 100")
 
+#define TEXT_MAIL_STATUS_NOT_CREATED		N_("Mail project not created")
+#define TEXT_MAIL_STATUS_CREATED		N_("Mail project created")
+#define TEXT_MAIL_STATUS_CHANGED		N_("Mail project changed")
+#define TEXT_MAIL_STATUS_ERR_READ_PROJECT	N_("Error reading mailproject")
+#define TEXT_MAIL_STATUS_POP3_CONNECTION_FAILED	N_("POP3 connection failed")
+#define TEXT_MAIL_STATUS_POP3_LOGIN_FAILED	N_("POP3 login failed")
+#define TEXT_MAIL_STATUS_SMTP_CONNECTION_FAILED	N_("SMTP connection failed")
+#define TEXT_MAIL_STATUS_SMTP_ERR_FROM		N_("From entry not accepted")
+#define TEXT_MAIL_STATUS_SMTP_ERR_RCPT		N_("Receiver entry not accepted")
+#define TEXT_MAIL_STATUS_SMTP_ERR_DATA		N_("Mail data not accepted")
+#define TEXT_MAIL_STATUS_SENDING		N_("Sending mail")
+#define TEXT_MAIL_STATUS_SENT			N_("Mail has been sent")
+
+#define TEXT_FAX_STATUS_NOT_CREATED		N_("Fax project not created")
+#define TEXT_FAX_STATUS_CREATED			N_("Fax project created")
+#define TEXT_FAX_STATUS_CHANGED			N_("Fax project changed")
+#define TEXT_FAX_STATUS_QUEUEING_FAX		N_("Queueing Fax")
+#define TEXT_FAX_STATUS_FAX_QUEUED		N_("Fax is queued")
 #endif
